@@ -35,6 +35,7 @@ class CredentialLibraryVault(
         *,
         credential_store_id: builtins.str,
         path: builtins.str,
+        credential_mapping_overrides: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         credential_type: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         http_method: typing.Optional[builtins.str] = None,
@@ -54,6 +55,7 @@ class CredentialLibraryVault(
         :param id: The scoped construct ID. Must be unique amongst siblings in the same scope
         :param credential_store_id: The ID of the credential store that this library belongs to. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#credential_store_id CredentialLibraryVault#credential_store_id}
         :param path: The path in Vault to request credentials from. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#path CredentialLibraryVault#path}
+        :param credential_mapping_overrides: The credential mapping override. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#credential_mapping_overrides CredentialLibraryVault#credential_mapping_overrides}
         :param credential_type: The type of credential the library generates. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#credential_type CredentialLibraryVault#credential_type}
         :param description: The Vault credential library description. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#description CredentialLibraryVault#description}
         :param http_method: The HTTP method the library uses when requesting credentials from Vault. Defaults to 'GET'. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#http_method CredentialLibraryVault#http_method}
@@ -68,12 +70,34 @@ class CredentialLibraryVault(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CredentialLibraryVault.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                credential_store_id: builtins.str,
+                path: builtins.str,
+                credential_mapping_overrides: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                credential_type: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                http_method: typing.Optional[builtins.str] = None,
+                http_request_body: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = CredentialLibraryVaultConfig(
             credential_store_id=credential_store_id,
             path=path,
+            credential_mapping_overrides=credential_mapping_overrides,
             credential_type=credential_type,
             description=description,
             http_method=http_method,
@@ -90,6 +114,10 @@ class CredentialLibraryVault(
 
         jsii.create(self.__class__, self, [scope, id, config])
 
+    @jsii.member(jsii_name="resetCredentialMappingOverrides")
+    def reset_credential_mapping_overrides(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetCredentialMappingOverrides", []))
+
     @jsii.member(jsii_name="resetCredentialType")
     def reset_credential_type(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetCredentialType", []))
@@ -124,6 +152,13 @@ class CredentialLibraryVault(
     def id(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "id"))
 
+    @builtins.property
+    @jsii.member(jsii_name="credentialMappingOverridesInput")
+    def credential_mapping_overrides_input(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "credentialMappingOverridesInput"))
+
     @builtins.property
     @jsii.member(jsii_name="credentialStoreIdInput")
     def credential_store_id_input(self) -> typing.Optional[builtins.str]:
@@ -159,6 +194,25 @@ class CredentialLibraryVault(
     def path_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pathInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="credentialMappingOverrides")
+    def credential_mapping_overrides(
+        self,
+    ) -> typing.Mapping[builtins.str, builtins.str]:
+        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "credentialMappingOverrides"))
+
+    @credential_mapping_overrides.setter
+    def credential_mapping_overrides(
+        self,
+        value: typing.Mapping[builtins.str, builtins.str],
+    ) -> None:
+        if __debug__:
+            def stub(value: typing.Mapping[builtins.str, builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "credentialMappingOverrides", value)
+
     @builtins.property
     @jsii.member(jsii_name="credentialStoreId")
     def credential_store_id(self) -> builtins.str:
@@ -167,7 +221,9 @@ class CredentialLibraryVault(
     @credential_store_id.setter
     def credential_store_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialLibraryVault, "credential_store_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "credentialStoreId", value)
 
@@ -179,7 +235,9 @@ class CredentialLibraryVault(
     @credential_type.setter
     def credential_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialLibraryVault, "credential_type").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "credentialType", value)
 
@@ -191,7 +249,9 @@ class CredentialLibraryVault(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialLibraryVault, "description").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -203,7 +263,9 @@ class CredentialLibraryVault(
     @http_method.setter
     def http_method(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialLibraryVault, "http_method").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "httpMethod", value)
 
@@ -215,7 +277,9 @@ class CredentialLibraryVault(
     @http_request_body.setter
     def http_request_body(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialLibraryVault, "http_request_body").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "httpRequestBody", value)
 
@@ -227,7 +291,9 @@ class CredentialLibraryVault(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialLibraryVault, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -239,7 +305,9 @@ class CredentialLibraryVault(
     @path.setter
     def path(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialLibraryVault, "path").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "path", value)
 
@@ -257,6 +325,7 @@ class CredentialLibraryVault(
         "provisioners": "provisioners",
         "credential_store_id": "credentialStoreId",
         "path": "path",
+        "credential_mapping_overrides": "credentialMappingOverrides",
         "credential_type": "credentialType",
         "description": "description",
         "http_method": "httpMethod",
@@ -277,6 +346,7 @@ class CredentialLibraryVaultConfig(cdktf.TerraformMetaArguments):
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
         credential_store_id: builtins.str,
         path: builtins.str,
+        credential_mapping_overrides: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         credential_type: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
         http_method: typing.Optional[builtins.str] = None,
@@ -293,6 +363,7 @@ class CredentialLibraryVaultConfig(cdktf.TerraformMetaArguments):
         :param provisioners: 
         :param credential_store_id: The ID of the credential store that this library belongs to. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#credential_store_id CredentialLibraryVault#credential_store_id}
         :param path: The path in Vault to request credentials from. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#path CredentialLibraryVault#path}
+        :param credential_mapping_overrides: The credential mapping override. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#credential_mapping_overrides CredentialLibraryVault#credential_mapping_overrides}
         :param credential_type: The type of credential the library generates. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#credential_type CredentialLibraryVault#credential_type}
         :param description: The Vault credential library description. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#description CredentialLibraryVault#description}
         :param http_method: The HTTP method the library uses when requesting credentials from Vault. Defaults to 'GET'. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#http_method CredentialLibraryVault#http_method}
@@ -302,7 +373,26 @@ class CredentialLibraryVaultConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(CredentialLibraryVaultConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                credential_store_id: builtins.str,
+                path: builtins.str,
+                credential_mapping_overrides: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                credential_type: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                http_method: typing.Optional[builtins.str] = None,
+                http_request_body: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -312,6 +402,7 @@ class CredentialLibraryVaultConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
             check_type(argname="argument credential_store_id", value=credential_store_id, expected_type=type_hints["credential_store_id"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
+            check_type(argname="argument credential_mapping_overrides", value=credential_mapping_overrides, expected_type=type_hints["credential_mapping_overrides"])
             check_type(argname="argument credential_type", value=credential_type, expected_type=type_hints["credential_type"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument http_method", value=http_method, expected_type=type_hints["http_method"])
@@ -335,6 +426,8 @@ class CredentialLibraryVaultConfig(cdktf.TerraformMetaArguments):
             self._values["provider"] = provider
         if provisioners is not None:
             self._values["provisioners"] = provisioners
+        if credential_mapping_overrides is not None:
+            self._values["credential_mapping_overrides"] = credential_mapping_overrides
         if credential_type is not None:
             self._values["credential_type"] = credential_type
         if description is not None:
@@ -426,6 +519,17 @@ class CredentialLibraryVaultConfig(cdktf.TerraformMetaArguments):
         assert result is not None, "Required property 'path' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def credential_mapping_overrides(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+        '''The credential mapping override.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary/r/credential_library_vault#credential_mapping_overrides CredentialLibraryVault#credential_mapping_overrides}
+        '''
+        result = self._values.get("credential_mapping_overrides")
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
+
     @builtins.property
     def credential_type(self) -> typing.Optional[builtins.str]:
         '''The type of credential the library generates.
