@@ -76,7 +76,31 @@ class CredentialStoreVault(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CredentialStoreVault.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                address: builtins.str,
+                scope_id: builtins.str,
+                token: builtins.str,
+                ca_cert: typing.Optional[builtins.str] = None,
+                client_certificate: typing.Optional[builtins.str] = None,
+                client_certificate_key: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+                namespace: typing.Optional[builtins.str] = None,
+                tls_server_name: typing.Optional[builtins.str] = None,
+                tls_skip_verify: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = CredentialStoreVaultConfig(
@@ -223,7 +247,9 @@ class CredentialStoreVault(
     @address.setter
     def address(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "address").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "address", value)
 
@@ -235,7 +261,9 @@ class CredentialStoreVault(
     @ca_cert.setter
     def ca_cert(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "ca_cert").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "caCert", value)
 
@@ -247,7 +275,9 @@ class CredentialStoreVault(
     @client_certificate.setter
     def client_certificate(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "client_certificate").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientCertificate", value)
 
@@ -259,7 +289,9 @@ class CredentialStoreVault(
     @client_certificate_key.setter
     def client_certificate_key(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "client_certificate_key").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientCertificateKey", value)
 
@@ -271,7 +303,9 @@ class CredentialStoreVault(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "description").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -283,7 +317,9 @@ class CredentialStoreVault(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -295,7 +331,9 @@ class CredentialStoreVault(
     @namespace.setter
     def namespace(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "namespace").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "namespace", value)
 
@@ -307,7 +345,9 @@ class CredentialStoreVault(
     @scope_id.setter
     def scope_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "scope_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "scopeId", value)
 
@@ -319,7 +359,9 @@ class CredentialStoreVault(
     @tls_server_name.setter
     def tls_server_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "tls_server_name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tlsServerName", value)
 
@@ -334,7 +376,9 @@ class CredentialStoreVault(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "tls_skip_verify").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tlsSkipVerify", value)
 
@@ -346,7 +390,9 @@ class CredentialStoreVault(
     @token.setter
     def token(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CredentialStoreVault, "token").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "token", value)
 
@@ -421,7 +467,29 @@ class CredentialStoreVaultConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(CredentialStoreVaultConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                address: builtins.str,
+                scope_id: builtins.str,
+                token: builtins.str,
+                ca_cert: typing.Optional[builtins.str] = None,
+                client_certificate: typing.Optional[builtins.str] = None,
+                client_certificate_key: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+                namespace: typing.Optional[builtins.str] = None,
+                tls_server_name: typing.Optional[builtins.str] = None,
+                tls_skip_verify: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
