@@ -76,7 +76,31 @@ class HostCatalogPlugin(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HostCatalogPlugin.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                scope_id: builtins.str,
+                attributes_json: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                internal_force_update: typing.Optional[builtins.str] = None,
+                internal_hmac_used_for_secrets_config_hmac: typing.Optional[builtins.str] = None,
+                internal_secrets_config_hmac: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+                plugin_id: typing.Optional[builtins.str] = None,
+                plugin_name: typing.Optional[builtins.str] = None,
+                secrets_hmac: typing.Optional[builtins.str] = None,
+                secrets_json: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = HostCatalogPluginConfig(
@@ -221,7 +245,9 @@ class HostCatalogPlugin(
     @attributes_json.setter
     def attributes_json(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "attributes_json").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "attributesJson", value)
 
@@ -233,7 +259,9 @@ class HostCatalogPlugin(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "description").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -245,7 +273,9 @@ class HostCatalogPlugin(
     @internal_force_update.setter
     def internal_force_update(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "internal_force_update").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalForceUpdate", value)
 
@@ -257,7 +287,9 @@ class HostCatalogPlugin(
     @internal_hmac_used_for_secrets_config_hmac.setter
     def internal_hmac_used_for_secrets_config_hmac(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "internal_hmac_used_for_secrets_config_hmac").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalHmacUsedForSecretsConfigHmac", value)
 
@@ -269,7 +301,9 @@ class HostCatalogPlugin(
     @internal_secrets_config_hmac.setter
     def internal_secrets_config_hmac(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "internal_secrets_config_hmac").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalSecretsConfigHmac", value)
 
@@ -281,7 +315,9 @@ class HostCatalogPlugin(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -293,7 +329,9 @@ class HostCatalogPlugin(
     @plugin_id.setter
     def plugin_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "plugin_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "pluginId", value)
 
@@ -305,7 +343,9 @@ class HostCatalogPlugin(
     @plugin_name.setter
     def plugin_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "plugin_name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "pluginName", value)
 
@@ -317,7 +357,9 @@ class HostCatalogPlugin(
     @scope_id.setter
     def scope_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "scope_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "scopeId", value)
 
@@ -329,7 +371,9 @@ class HostCatalogPlugin(
     @secrets_hmac.setter
     def secrets_hmac(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "secrets_hmac").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "secretsHmac", value)
 
@@ -341,7 +385,9 @@ class HostCatalogPlugin(
     @secrets_json.setter
     def secrets_json(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HostCatalogPlugin, "secrets_json").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "secretsJson", value)
 
@@ -416,7 +462,29 @@ class HostCatalogPluginConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(HostCatalogPluginConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                scope_id: builtins.str,
+                attributes_json: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                internal_force_update: typing.Optional[builtins.str] = None,
+                internal_hmac_used_for_secrets_config_hmac: typing.Optional[builtins.str] = None,
+                internal_secrets_config_hmac: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+                plugin_id: typing.Optional[builtins.str] = None,
+                plugin_name: typing.Optional[builtins.str] = None,
+                secrets_hmac: typing.Optional[builtins.str] = None,
+                secrets_json: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
